pub enum SfuCoreError {
Transport(TransportAdapterError),
CapabilityProjection(TransportAdapterError),
SessionNegotiationRejected,
SessionRefreshRejected,
SubscriptionUpdateRejected,
}Variants
Transport(TransportAdapterError)
media transport command failed
CapabilityProjection(TransportAdapterError)
accepted answer did not yield client capabilities needed by room state
SessionNegotiationRejected
initial answer was valid transport input but stale for room state
SessionRefreshRejected
refresh answer was valid transport input but stale for room state
SubscriptionUpdateRejected
subscription intent targeted a stale or invalid room connection
Implementations
Sourceimpl SfuCoreError
impl SfuCoreError
Sourcepub const fn is_client_error(self) -> bool
pub const fn is_client_error(self) -> bool
whether this error should close the client as a protocol fault